---
title: fixpack
keywords: documentation
layout: documentation
sidebar: mq_install_sidebar
toc: false
---
## Overview

The defined type `mq_install::fixoack` allows you to install specified fixpacks on your system. The fixpacks will be added on top of your software installation managed by [`ora_install::software`](./software).

The simples way to use it is:

``` puppet
mq_install::fixpack{'9.1.0.1':
  source_locaation => '/nfs_share/software'
}
```
Based on this puppet code, puppet will install fixpack 9.1.0.1. Because the installation of the fixpack requires all MQ processes to be stopped, this code will stop **ALL** MQ managers when it finds it needs to install the fixpack. 

When the `mq_install::fixpack' is part of a larger set of Puppet code also managing MQ managers and queue's, that definition will restart the required MQ queue masnagers.




## Attributes



Attribute Name                              | Short Description                                                                                    |
------------------------------------------- | ---------------------------------------------------------------------------------------------------- |
[logoutput](#fixpack_logoutput)             | If you want to see the output of the `exec` resources in the type, you can set this value to `true`. |
[source_location](#fixpack_source_location) | The location of the MQ software.                                                                     |
[title](#fixpack_title)                     | The name of the class.                                                                               |
[tmp_dir](#fixpack_tmp_dir)                 | This defined type uses a temporary directory.                                                        |




### title<a name='fixpack_title'>

The name of the class.


[Back to overview of fixpack](#attributes)

### source_location<a name='fixpack_source_location'>

The location of the MQ software.

Here is an example on how to use this:

    class { '::mq_install::...':
      ...
      source_location => '/software',
      ...
    }

Type: `String`


[Back to overview of fixpack](#attributes)

### tmp_dir<a name='fixpack_tmp_dir'>

This defined type uses a temporary directory. By default this is `\tmp`. If you want to use an other directory for this, you must specify this parameter.

Here is an example on how to use this:

    class { '::mq_install::...':
      ...
      tmp_dir => '/my_tmp_dir',
      ...
    }

On systems with a secured `/tmp` direcory, you MUST specify the `tmp_dir` parameter and specify a directory that puppet is allowed to execute scripts from. It must also have enough space to receive the extracted MQ installation kit.

Type: `String`

Default:`'/tmp'`

[Back to overview of fixpack](#attributes)

### logoutput<a name='fixpack_logoutput'>

If you want to see the output of the `exec` resources in the type, you can set this value to `true`. The default is `on_failure`.

Here is an example on how to use this:

    class { '::mq_install::...':
      ...
      logoutput => true,
      ...
    }

Type: `Variant[Enum['on_failure'], Boolean]`

Default:`'on_failure'`

[Back to overview of fixpack](#attributes)
